@@ -4,7 +4,7 @@ import click
 from urllib.parse import quote
 from rich.console import Console
 
-from doing.utils import get_repo_name, run_command, get_current_work_item_id
+from doing.utils import get_repo_name, run_command, get_current_work_item_id, get_current_pr_id
 from doing.options import get_config
 from doing.pr.open_pr import cmd_open_pr
 from doing.issue.open_issue import cmd_open_issue
@@ -107,6 +107,7 @@ def issue(work_item_id):
         work_item_id = get_current_work_item_id()
     cmd_open_issue(work_item_id)
 
+
 @open.command()
 def issues():
     """
@@ -125,11 +126,17 @@ def issues():
 
 
 @open.command()
-@click.argument("pullrequest_id")
+@click.argument("pullrequest_id", default=-1)
 def pr(pullrequest_id):
     """
-    Open a specific PULLREQUEST_ID. '!' prefix is allowed.
+    Open a specific PULLREQUEST_ID.
+
+    When not provided attempt to auto-detect the PULLREQUEST_ID using the git branch name.
+
+    '!' prefix is allowed.
     """
+    if pullrequest_id == -1:
+        pullrequest_id = get_current_pr_id()
     cmd_open_pr(pullrequest_id)
 
 
@@ -143,3 +150,38 @@ def branch(branch_name):
     organization = get_config("organization")
 
     click.launch(f"{organization}/{project}/_git/{get_repo_name()}?version=GB{branch_name}")
+
+
+@open.command()
+def branches():
+    """
+    Open an overview of the repositories' branches.
+    """
+    project = get_config("project")
+    organization = get_config("organization")
+
+    url = f"{organization}/{project}/_git/{get_repo_name()}/branches"
+    click.launch(url)
+
+
+@open.command()
+def policies():
+    """
+    Open repository policy settings.
+
+    Will show the default branch policies by default.
+    """
+    project = get_config("project")
+    organization = get_config("organization")
+
+    repo_name = get_repo_name()
+    repo = run_command(f"az repos show --repository '{repo_name}'")
+
+    repo_id = repo.get("id")
+    assert len(repo_id) > 0
+    default_branch = repo.get("defaultBranch").split("/")[-1]
+    assert len(default_branch) > 0
+
+    url = f"{organization}/{project}/_settings/repositories?repo={repo_id}"
+    url += f"&_a=policiesMid&refs=refs%2Fheads%2F{default_branch}"
+    click.launch(url)
